from django.core import meta

class Tag(meta.Model):
	""" This model stands for a tag that can be attached to the posts """
	label = meta.CharField("Tag", maxlength=50, blank=False)

	def __repr__(self):
		return self.label

	class META:
		admin = meta.Admin()

class Post(meta.Model):
	""" This model stands for a single post in the blog system """
	title = meta.CharField("Title", maxlength=255, blank=False)
	content = meta.TextField("Content", blank=False)
	is_published = meta.BooleanField("Is it published")
	published_at = meta.DateTimeField("It was published at", auto_now_add=True)
	slug = meta.SlugField("Post slug", prepopulate_from=("title",))
	tags = meta.ManyToManyField(Tag, verbose_name="Tags")

	def __repr__(self):
		return self.title

	def get_absolute_url(self):
        		return "/%d%02d%02d/%s/" % (self.published_at.year, self.published_at.month, self.published_at.day, self.slug)

	class META:
		admin = meta.Admin(
			fields = (
        			('Basic', {'fields': ('title', 'content', 'tags')}),
				('Advanced', {'fields': ('slug', 'is_published', 'published_at'), 'classes': 'collapse'}),
	    		),
        		list_display = ('title', 'published_at'),
			list_filter = ['tags', 'published_at'],
			search_fields = ['content', 'title'],
		)
		ordering = ('-published_at',)

class Comment(meta.Model):
	""" This model stands for a comment related to a post """
	author = meta.CharField("Author", maxlength=200, blank=False)
	email = meta.EmailField("Email", blank=False)
	content = meta.TextField("Comment", blank=False)
	posted_at = meta.DateTimeField("Posted at", auto_now_add=True, editable=False, blank=False)
	post = meta.ForeignKey(Post)

	def __repr__(self):
		return self.author;
	
	class META:
		admin = meta.Admin(
			list_display = ('author', 'email', 'posted_at', 'post',),
			list_filter = ('posted_at', 'post',),
			search_fields = ('author', 'email', 'comment',),
		)
